@@ -4,7 +4,7 @@ use warnings;
 package Getopt::Lucid;
 # ABSTRACT: Clear, readable syntax for command line processing
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 our @EXPORT_OK = qw(Switch Counter Param List Keypair);
 our %EXPORT_TAGS = ( all => [ @EXPORT_OK ] );
@@ -798,7 +798,7 @@ Getopt::Lucid - Clear, readable syntax for command line processing
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -1576,7 +1576,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords David Golden Precious Kevin McGrath Nova Patch Robert Bohne
+=for stopwords David Golden Precious James E Keenan Kevin McGrath Nova Patch Robert Bohne
 
 =over 4
 
@@ -1590,6 +1590,10 @@ David Precious <davidp@preshweb.co.uk>
 
 =item *
 
+James E Keenan <jkeenan@cpan.org>
+
+=item *
+
 Kevin McGrath <kmcgrath@cpan.org>
 
 =item *
@@ -1604,7 +1608,7 @@ Robert Bohne <rbo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by David Golden.
+This software is Copyright (c) 2017 by David Golden.
 
 This is free software, licensed under:
 
